@@ -11,6 +11,7 @@ import (
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/service/ec2"
 	ec2types "github.com/aws/aws-sdk-go-v2/service/ec2/types"
+
 	"github.com/weaveworks/eksctl/pkg/testutils/mockprovider"
 
 	. "github.com/onsi/ginkgo/v2"
@@ -35,10 +36,12 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 		fakeVPCImporter   *vpcfakes.FakeImporter
 		fakeBootstrapper  *bootstrapfakes.FakeBootstrapper
 		p                 = mockprovider.NewMockProvider()
+		skipEgressRules   bool
 	)
 
 	BeforeEach(func() {
 		forceAddCNIPolicy = false
+		skipEgressRules = false
 		fakeVPCImporter = new(vpcfakes.FakeImporter)
 		fakeBootstrapper = new(bootstrapfakes.FakeBootstrapper)
 		cfg, ng = newClusterAndNodeGroup()
@@ -51,7 +54,14 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 	})
 
 	JustBeforeEach(func() {
-		ngrs = builder.NewNodeGroupResourceSet(p.MockEC2(), p.MockIAM(), cfg, ng, fakeBootstrapper, forceAddCNIPolicy, fakeVPCImporter)
+		ngrs = builder.NewNodeGroupResourceSet(p.MockEC2(), p.MockIAM(), builder.NodeGroupOptions{
+			ClusterConfig:     cfg,
+			NodeGroup:         ng,
+			Bootstrapper:      fakeBootstrapper,
+			ForceAddCNIPolicy: forceAddCNIPolicy,
+			VPCImporter:       fakeVPCImporter,
+			SkipEgressRules:   skipEgressRules,
+		})
 	})
 
 	Describe("AddAllResources", func() {
@@ -1312,6 +1322,24 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 					Expect(properties.LaunchTemplateData.Monitoring.Enabled).To(Equal(true))
 				})
 			})
+
+			Context("skipEgressRules is false", func() {
+				It("should add egress rules", func() {
+					Expect(ngTemplate.Resources).To(HaveKey("EgressInterCluster"))
+					Expect(ngTemplate.Resources).To(HaveKey("EgressInterClusterAPI"))
+				})
+			})
+
+			Context("skipEgressRules is true", func() {
+				BeforeEach(func() {
+					skipEgressRules = true
+				})
+
+				It("should not add egress rules", func() {
+					Expect(ngTemplate.Resources).NotTo(HaveKey("EgressInterCluster"))
+					Expect(ngTemplate.Resources).NotTo(HaveKey("EgressInterClusterAPI"))
+				})
+			})
 		})
 	})
 
